archived_value_mut

Function archived_value_mut 

pub unsafe fn archived_value_mut<T: Archive + ?Sized>(
    bytes: Pin<&mut [u8]>,
    pos: usize,
) -> Pin<&mut T::Archived>
Casts a mutable archived value from the given byte slice at the given position.

This helps avoid situations where lifetimes get inappropriately assigned and allow buffer mutation after getting archived value references.

Safety

A T::Archived must be archived at the given position in the byte slice.